==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/OwnerReferenceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OwnerReferenceFluent<A extends OwnerReferenceFluent<A>> extends BaseFluent<A>{
  public OwnerReferenceFluent() {
  }
  public OwnerReferenceFluent(OwnerReference instance) {
    instance = (instance != null ? instance : new OwnerReference());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withBlockOwnerDeletion(instance.getBlockOwnerDeletion());
      this.withController(instance.getController());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withUid(instance.getUid());
      this.withApiVersion(instance.getApiVersion());
      this.withBlockOwnerDeletion(instance.getBlockOwnerDeletion());
      this.withController(instance.getController());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withUid(instance.getUid());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private Boolean blockOwnerDeletion;
  private Boolean controller;
  private String kind;
  private String name;
  private String uid;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public Boolean getBlockOwnerDeletion() {
    return this.blockOwnerDeletion;
  }
  public A withBlockOwnerDeletion(Boolean blockOwnerDeletion) {
    this.blockOwnerDeletion=blockOwnerDeletion; return (A) this;
  }
  public boolean hasBlockOwnerDeletion() {
    return this.blockOwnerDeletion != null;
  }
  public Boolean getController() {
    return this.controller;
  }
  public A withController(Boolean controller) {
    this.controller=controller; return (A) this;
  }
  public boolean hasController() {
    return this.controller != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public boolean hasKind() {
    return this.kind != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getUid() {
    return this.uid;
  }
  public A withUid(String uid) {
    this.uid=uid; return (A) this;
  }
  public boolean hasUid() {
    return this.uid != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OwnerReferenceFluent that = (OwnerReferenceFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(blockOwnerDeletion, that.blockOwnerDeletion)) return false;

    if (!java.util.Objects.equals(controller, that.controller)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(uid, that.uid)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  blockOwnerDeletion,  controller,  kind,  name,  uid,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (blockOwnerDeletion != null) { sb.append("blockOwnerDeletion:"); sb.append(blockOwnerDeletion + ","); }
    if (controller != null) { sb.append("controller:"); sb.append(controller + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withBlockOwnerDeletion() {
    return withBlockOwnerDeletion(true);
  }
  public A withController() {
    return withController(true);
  }
  
}

==> kubernetes-model-core-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/OwnerReferenceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OwnerReferenceFluent<A extends OwnerReferenceFluent<A>> extends BaseFluent<A>{
  public OwnerReferenceFluent() {
  }
  
  public OwnerReferenceFluent(OwnerReference instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private Boolean blockOwnerDeletion;
  private Boolean controller;
  private String kind;
  private String name;
  private String uid;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OwnerReference instance) {
    instance = (instance != null ? instance : new OwnerReference());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withBlockOwnerDeletion(instance.getBlockOwnerDeletion());
        this.withController(instance.getController());
        this.withKind(instance.getKind());
        this.withName(instance.getName());
        this.withUid(instance.getUid());
        this.withApiVersion(instance.getApiVersion());
        this.withBlockOwnerDeletion(instance.getBlockOwnerDeletion());
        this.withController(instance.getController());
        this.withKind(instance.getKind());
        this.withName(instance.getName());
        this.withUid(instance.getUid());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public Boolean getBlockOwnerDeletion() {
    return this.blockOwnerDeletion;
  }
  
  public A withBlockOwnerDeletion(Boolean blockOwnerDeletion) {
    this.blockOwnerDeletion=blockOwnerDeletion; return (A) this;
  }
  
  public boolean hasBlockOwnerDeletion() {
    return this.blockOwnerDeletion != null;
  }
  
  public Boolean getController() {
    return this.controller;
  }
  
  public A withController(Boolean controller) {
    this.controller=controller; return (A) this;
  }
  
  public boolean hasController() {
    return this.controller != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getUid() {
    return this.uid;
  }
  
  public A withUid(String uid) {
    this.uid=uid; return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OwnerReferenceFluent that = (OwnerReferenceFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(blockOwnerDeletion, that.blockOwnerDeletion)) return false;
  
    if (!java.util.Objects.equals(controller, that.controller)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(uid, that.uid)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  blockOwnerDeletion,  controller,  kind,  name,  uid,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (blockOwnerDeletion != null) { sb.append("blockOwnerDeletion:"); sb.append(blockOwnerDeletion + ","); }
    if (controller != null) { sb.append("controller:"); sb.append(controller + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withBlockOwnerDeletion() {
    return withBlockOwnerDeletion(true);
  }
  
  public A withController() {
    return withController(true);
  }
  

}
